@@ -7,6 +7,7 @@
 @homepage: https://gitlab.com/Malfatti/SciScripts
 """
 
+print('[Analysis.ABRs] Importing dependencies...')
 import numpy as np
 import os
 
@@ -16,6 +17,7 @@ from glob import glob
 from sciscripts.Analysis import Analysis
 from sciscripts.Analysis.Plot import Plot
 from sciscripts.IO import IO
+print('[Analysis.ABRs] Done.')
 
 ## Level 0
 def ABRPerCh(Data, Rate, TTLs, ABRCh, TimeWindow, FilterFreq, FilterOrder=4, FilterCoeff='butter', Filter='bandpass'):
@@ -43,8 +45,6 @@ def LatencyToPeaks(ABRs, X=[], RefKey=None, Std=1):
         return(None)
 
     if not RefKey: RefKey = Recs[0]
-    # BestCh = [np.mean(ABRs[RefKey][:,Ch]**2)**0.5 for Ch in range(ABRs[RefKey].shape[1])]
-    # BestCh = BestCh.index(max(BestCh))
     BestCh = Analysis.GetStrongestCh(ABRs[RefKey])
 
     if len(X):
@@ -56,9 +56,7 @@ def LatencyToPeaks(ABRs, X=[], RefKey=None, Std=1):
         # Peaks = [Analysis.GetPeaks(ABRs[Rec][:,BestCh], Std=Std) for Rec in Recs]
 
     Peaks = [_['Pos'] for _ in Peaks]
-    # print(Peaks)
     if len(X): Peaks = [P[X[P] > 0] for P in Peaks]
-    # print(Peaks)
 
     if not len(Peaks[0]):
         AllPeaks = np.ones((len(Recs),1), dtype=int)*-1
@@ -139,14 +137,6 @@ def LatencyPerFreq(Files, Freqs, Std=1):
         X = '/'.join(File.split('/')[:-1])+'/X.dat'
         X = IO.Bin.Read(X)[0]
 
-        # Rev = False if '0' in ABRs else True
-        # Recs = sorted(list(ABRs.keys()), reverse=Rev)
-        # if not RefKey: RefKey = Recs[0]
-
-        # if ABRs[RefKey][0,0] != ABRs[RefKey][0,0]:
-        #     print('Freq', Freqs[F], 'contains NaNs. Skipping...')
-        #     continue
-
         Latencies[Freqs[F]] = LatencyToPeaks(ABRs, X, Std=Std)
 
         Thrs = [np.where((Latencies[Freqs[F]][:,_] == max(Latencies[Freqs[F]][:,_])))[0][-1] for _ in range(Latencies[Freqs[F]].shape[1])]
@@ -214,52 +204,6 @@ def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq, Recs='all', Inten
             Save=Save_R, ReturnX=False, Return=Return
         )
 
-    # if type(TTLCh) == list:
-    #     if Intensities:
-    #         ABRs = {
-    #             Intensities[R]: Single(
-    #                 Data[Rec], Rate, ABRCh, IO.Bin.Read(TTLCh[R])[0],
-    #                 TimeWindow, FilterFreq, Save=Save+'/'+Intensities[R],
-    #                 ReturnX=False, Return=Return
-    #             ) if type(TTLCh[R]) == str else Single(
-    #                 Data[Rec], Rate, ABRCh, TTLCh[R],
-    #                 TimeWindow, FilterFreq, Save=Save+'/'+Intensities[R],
-    #                 ReturnX=False, Return=Return
-    #             )
-    #             for R,Rec in enumerate(Recs)
-    #         }
-    #     else:
-    #         ABRs = {
-    #             Rec: Single(
-    #                 Data[Rec], Rate, ABRCh, IO.Bin.Read(TTLCh[R])[0],
-    #                 TimeWindow, FilterFreq, Save=Save+'/'+Rec,
-    #                 ReturnX=False, Return=Return
-    #             ) if type(TTLCh[R]) == str else Single(
-    #                 Data[Rec], Rate, ABRCh, TTLCh[R],
-    #                 TimeWindow, FilterFreq, Save=Save+'/'+Rec,
-    #                 ReturnX=False, Return=Return
-    #             )
-    #             for R,Rec in enumerate(Recs)
-    #         }
-
-    # else:
-    #     if Intensities:
-    #         ABRs = {
-    #             Intensities[R]: Single(
-    #                 Data[Rec], Rate, ABRCh, TTLCh, TimeWindow, FilterFreq,
-    #                 Save=Save+'/'+Intensities[R], ReturnX=False, Return=Return
-    #             )
-    #             for R,Rec in enumerate(Recs)
-    #         }
-    #     else:
-    #         ABRs = {
-    #             Rec: Single(
-    #                 Data[Rec], Rate, ABRCh, TTLCh, TimeWindow, FilterFreq,
-    #                 Save=Save+'/'+Rec, ReturnX=False, Return=Return
-    #             )
-    #             for Rec in Recs
-    #         }
-
     X = np.arange(int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate))*1000/Rate
 
     if Save:
@@ -329,7 +273,7 @@ def Session(Folders, Freqs, Intensities, ABRCh, TTLCh, TimeWindow, FilterFreq, P
         if len(Data.keys()) == 1: Proc = list(Data.keys())[0]
         else: ChNo, Proc = IO.OpenEphys.GetChNoAndProcs(Folder+'/settings.xml')
 
-        Data, Rate = Data[Proc], Rate[Proc]
+        Data, Rate = Data[Proc]['0'], Rate[Proc]['0']
         print('')
         print([_.shape for _ in Data.values()])
 
@@ -344,30 +288,7 @@ def Session(Folders, Freqs, Intensities, ABRCh, TTLCh, TimeWindow, FilterFreq, P
         TTLCh_F = TTLCh[F] if type(TTLCh) == list else TTLCh
         ABRCh_F = ABRCh[F] if type(ABRCh[0]) == list else ABRCh
 
-        # # Overrides - Fixes for specific errors
-        # if '2016-05-12_15-04-15' in Folder: TTLCh_F = 18
-        # if '2017-07-03_12-37-32_10-12' in Folder: del(Data['1'], Data['2'])
-        # if '2017-07-03_12-27-15_12-14' in Folder: del(Data['3'], Data['5'])
-        # if Folder.split('/')[-1] in [
-        #     '2017-07-18_20-06-57_14-16',
-        #     '2017-07-18_18-51-41_14-16',
-        #     '2017-07-18_18-34-11_12-14',
-        #     '2017-07-18_18-40-39_08-10',
-        #     '2017-07-18_20-01-22_12-14',
-        #     '2017-07-03_15-30-09_09-11B',
-        #     '2017-07-03_15-41-28_10-12B',
-        #     '2017-07-03_12-37-32_10-12',
-        #     '2017-07-03_12-27-15_12-14',
-        #     '2017-07-18_12-55-21_09-11',
-        #     '2017-07-18_16-17-37_14-16',
-        #     '2017-07-18_16-23-10_09-11',
-        #     '2017-07-18_16-11-36_08-10'
-        # ]:
-        #     Data = {str(k): Data.pop(K) for k,K in enumerate(sorted(Data.keys()))}
-
         Multiple(Data, Rate, ABRCh_F, TTLCh_F, TimeWindow, FilterFreq, Recs='all', Intensities=Intensities, Save=SavePath, Return=False)
-        # Recs = sorted(list(ABRs.keys()))
-        # ABRs = {Intensities[R]: ABRs.pop(Rec) for R, Rec in enumerate(Recs)}
 
         del(Data)
 
@@ -378,14 +299,13 @@ def WriteRecAndTTLCh(Folders):
         print(Folder)
         Data, Rate = IO.DataLoader(Folder, Unit='uV', ChannelMap=[])
         if len(Data.keys()) == 1: Proc = list(Data.keys())[0]
-        Data, Rate = Data[Proc], Rate[Proc]
+        Data, Rate = Data[Proc]['0'], Rate[Proc]['0']
 
         InfoFile = glob(Folder+'/../*.dict')[0]
 
         for R, Rec in Data.items():
             print(R)
             Info = IO.Txt.Read(InfoFile)
-            # Info = IO.Txt.Dict_OldToNew(Info)
             TTLs = []
             if Info['DAqs']['TTLCh'] <= Rec.shape[1]:
                 TTLs = Analysis.QuantifyTTLsPerRec(True, Rec[:,Info['DAqs']['TTLCh']-1])
@@ -421,7 +341,7 @@ def WriteRecAndTTLCh(Folders):
     return(None)
 
 
-NoTTLsFile = os.environ['NEBULAPATH']+'/Documents/PhD/Notes/Experiments/NoTTLRecs.dict'
+NoTTLsFile = os.environ['AnalysisPath']+'/Experiments/NoTTLRecs.dict'
 
 def _PrintOptions():
     print('')
@@ -604,8 +524,6 @@ def FixTTLs(Data, Rate, DataInfo, Freq, Rec, AnalogTTLs):
 
 
 def GetTTLs(Data, Rate, DataInfo, DataFolder, AnalogTTLs=True, R=None, Freq=None):
-    # Temporary override
-
     TTLCh = DataInfo['DAqs']['TTLCh']
     ABRCh = DataInfo['DAqs']['RecCh']
 
@@ -661,25 +579,3 @@ def GetTTLs(Data, Rate, DataInfo, DataFolder, AnalogTTLs=True, R=None, Freq=None
     return(TTLs)
 
 
-# def ABRThresholdsTxtToHdf5(Override={}):
-#     if 'AnalysisFile' in Override: AnalysisFile =  Override['AnalysisFile']
-#     else: AnalysisFile = glob('*.hdf5')[0]
-
-#     if 'FileName' in Override: FileName =  Override['FileName']
-#     else: FileName = glob('*.txt')[0]
-
-#     with open(FileName, 'r') as F:
-#         Lines = [Line for Line in F]
-
-#     Lines = [Line.split() for Line in Lines]
-#     Exps = Lines[0][:]; del(Lines[0])
-#     Freqs = Lines[0][:]; del(Lines[0])
-
-#     ABRThresholds = {Exp: {} for Exp in Exps}
-#     for EInd, Exp in enumerate(Exps):
-#         for FInd, Freq in enumerate(Freqs):
-#             ABRThresholds[Exp][Freq] = float(Lines[EInd][FInd])
-
-#     IO.Txt.Write(ABRThresholds, AnalysisFile)
-#     return(None)
-
