@@ -8,16 +8,13 @@
 """
 
 print('[Analysis.Plot.Plot] Importing dependencies...')
-
 import os
 import numpy as np
 from itertools import accumulate#, combinations
 from matplotlib.colors import to_rgba
 from subprocess import check_output
 
-# from sciscripts.Analysis import Stats
 from sciscripts.Analysis.Analysis import Pairwise
-
 print('[Analysis.Plot.Plot] Done.')
 
 ## Level 0
@@ -75,7 +72,7 @@ def GetScreenInfo():
         Screen['DPI'] = [_.split('resolution')[1].split('\\n')[0].split('x')[0].split(' ')[-1] for _ in Screen['DPI']]
         Screen['DPI'] = [int(_) for _ in Screen['DPI']]
     except:
-        # Assuming 96 dpi
+        print('xdpyinfo not installed. Assuming a 96 dpi screen.')
         Screen['DPI'] = [96]
 
     try:
@@ -85,7 +82,7 @@ def GetScreenInfo():
         Screen['Size_px'] = [_.split('+')[0].split('x') for f in Size for _ in f.split(' ') if 'x' in _ and '+' in _]
         Screen['Size_px'] = [[int(_) for _ in s] for s in Screen['Size_px']]
     except:
-        # Assuming a 15" full HD screen
+        print('xrandr not installed. Assuming a 15.6" full HD screen.')
         Screen['Size_mm'] = [[344, 193]]
         Screen['Size_px'] = [[1920, 1080]]
 
@@ -220,6 +217,7 @@ def Set(Backend='TkCairo', Ax=None, Fig=None, AxArgs={}, FigTitle=None, Params=F
 
         if 'title' in AxArgs: Ax.set_title(AxArgs['title'])
 
+
         ## X
         if 'xlabel' in AxArgs: Ax.set_xlabel(AxArgs['xlabel'])
         if 'xlim' in AxArgs: Ax.set_xlim(AxArgs['xlim'])
@@ -239,23 +237,6 @@ def Set(Backend='TkCairo', Ax=None, Fig=None, AxArgs={}, FigTitle=None, Params=F
                           Ticks[Ticks <= Lim[1]][-1]]
                 Ax.spines['bottom'].set_bounds(Bounds)
 
-        # XTicks = Ax.get_xticks()
-        # if XLim is None:
-            # XLim = list(Ax.get_xlim())
-            # XInterval = Ax.xaxis.get_data_interval()
-            # Tolerance = (XInterval[1]-XInterval[0])*0.1
-
-            # if len(XTicks) and min(XInterval) > min(XTicks):
-                # XLim[0] = XTicks[XTicks<=min(XInterval)+Tolerance][-1]
-            # if len(XTicks) and max(XInterval) < max(XTicks):
-                # XLim[1] = XTicks[XTicks>=max(XInterval)-Tolerance][0]
-
-        # Ax.set_xlim(XLim)
-
-        # if len(XTicks):
-            # XBound = [XTicks[XTicks >= XLim[0]][0],
-                      # XTicks[XTicks <= XLim[1]][-1]]
-            # Ax.spines['bottom'].set_bounds(XBound[0], XBound[1])
 
         ## Y
         if 'ylabel' in AxArgs: Ax.set_ylabel(AxArgs['ylabel'])
@@ -276,46 +257,6 @@ def Set(Backend='TkCairo', Ax=None, Fig=None, AxArgs={}, FigTitle=None, Params=F
                           Ticks[Ticks <= Lim[1]][-1]]
                 Ax.spines['left'].set_bounds(Bounds)
 
-        # YTicks = Ax.get_yticks()
-        # if YLim is None:
-            # YLim = list(Ax.get_ylim())
-            # YInterval = Ax.yaxis.get_data_interval()
-            # Tolerance = (YInterval[1]-YInterval[0])*0.1
-
-            # if len(YTicks) and min(YInterval) > min(YTicks):
-                # YLim[0] = YTicks[YTicks<=min(YInterval)+Tolerance][-1]
-            # if len(YTicks) and max(YInterval) < max(YTicks):
-                # YLim[1] = YTicks[YTicks>=max(YInterval)-Tolerance][0]
-
-        # Ax.set_ylim(YLim)
-
-        # if len(YTicks):
-            # YBound = [YTicks[YTicks >= YLim[0]][0],
-                      # YTicks[YTicks <= YLim[1]][-1]]
-            # Ax.spines['left'].set_bounds(YBound[0], YBound[1])
-
-        # # YInterval = Ax.yaxis.get_data_interval()
-        # # Tolerance = (YInterval[1]-YInterval[0])*0.05
-
-        # # if YLim is None:# and YTicks is None:
-            # # YLim = list(Ax.get_ylim())
-            # # YTicks = Ax.get_yticks()
-
-            # # if len(YTicks) and min(YInterval) > min(YTicks):
-                # # YLim[0] = YTicks[YTicks<=min(YInterval)+Tolerance][-1]
-            # # if len(YTicks) and max(YInterval) < max(YTicks):
-                # # YLim[1] = YTicks[YTicks>=max(YInterval)-Tolerance][0]
-
-        # # if YTicks is None: YTicks = Ax.get_yticks()
-        # # YTicks = np.array(YTicks)
-
-        # # if YTicks is not None and len(YTicks):
-            # # YBound = [YTicks[YTicks >= YLim[0]][0],
-                      # # YTicks[YTicks <= YLim[1]][-1]]
-            # # Ax.spines['left'].set_bounds(YBound[0], YBound[1])
-            # # Ax.set_yticks(YTicks)
-
-        # # Ax.set_ylim(YLim)
 
         ## Z
         if 'zlim' in AxArgs:
@@ -638,9 +579,6 @@ def ScaleBar(
     SM._A = []
 
     Fig.colorbar(SM, ax=Ax, **ColorbarArgs)
-#     inset_axes = Return('inset_axes')
-#     Inset = inset_axes(Ax, width='5%', height='100%')
-#     Fig.colorbar(SM, cax=Inset, **ColorbarArgs)
 
     return(None)
 
