@@ -98,7 +98,7 @@ def InfoWrite(InfoFile, **All):
               'SoundPulseDur', 'SoundPauseAfterPulseDur', 'PauseBetweenIntensities',
               'System', 'Setup', 'CalibrationFile', 'SoundAmpF',
               'TTLAmpF', 'MicSens_dB', 'MicSens_VPa', 'BGIntensity',
-              'PulseIntensity', 'SoundBGDur', 'SoundGapDur',
+              'PulseIntensity', 'GapIntensity', 'SoundBGDur', 'SoundGapDur',
               'SoundBGPrePulseDur','SoundLoudPulseDur', 'SoundBGAfterPulseDur',
               'SoundBetweenStimDur', 'NoOfTrials', 'SoundBGAmpF',
               'SoundPulseAmpF','PrePost']:
@@ -106,11 +106,12 @@ def InfoWrite(InfoFile, **All):
             if 'Audio' not in DataInfo: DataInfo['Audio'] = {}
             DataInfo['Audio'][K] = All[K]
             if K == 'NoiseFrequency':
-                if type(All[K][0]) == list():
-                    DataInfo['Audio']['Freqs'] = ['-'.join([str(_) for _ in F])
-                                                  for F in All[K]]
-                else:
-                    DataInfo['Audio']['Freqs'] = [str(F) for F in All[K]]
+                if All[K]:
+                    if type(All[K][0]) == list():
+                        DataInfo['Audio']['Freqs'] = ['-'.join([str(_) for _ in F])
+                                                      for F in All[K]]
+                    else:
+                        DataInfo['Audio']['Freqs'] = [str(F) for F in All[K]]
 
     for K in ['LaserStimBlockNo', 'LaserPulseNo', 'LaserPauseBeforePulseDur',
               'LaserPulseDur', 'LaserPauseAfterPulseDur',
@@ -138,6 +139,10 @@ def InfoWrite(InfoFile, **All):
 
 
 def Dict_OldToNew(Info):
+    """
+    Function that updates very old InfoFiles to the current version.
+    Completely harmless if accidentaly used on current InfoFiles.
+    """
     if 'FileName' in Info: Info['InfoFile'] = Info.pop('FileName')
     if 'ExpInfo' not in Info: Info['ExpInfo'] = {}
 
