@@ -8,13 +8,12 @@
 """
 
 print('[IO.Wav] Importing dependencies...')
-import numpy as np
 import os
 
-from glob import glob
 from scipy.io import wavfile
 print('[IO.Wav] Done.')
 
+
 def Read(File):
     Rate, Data = wavfile.read(File)
     if len(Data.shape) == 1:
